@@ -9,6 +9,12 @@ check_can_create_state_output_file <- function( # nolint indeed a long function
   beastier::check_can_create_dir_for_state_output_file(beast2_options)
   if (file.exists(beast2_options$output_state_filename)) return()
 
+  dir.create(
+    path = dirname(beast2_options$output_state_filename),
+    showWarnings = FALSE,
+    recursive = TRUE
+  )
+
   # Use a more precise error message
   tryCatch(
     beastier::check_can_create_file(
