@@ -20,7 +20,10 @@ check_can_create_treelog_file <- function(
   testthat::expect_equal(ncol(matches), 2)
   treelog_filename <- matches[1, 2]
 
-  if (file.exists(treelog_filename)) return()
+  if (file.exists(treelog_filename)) {
+     file.remove(treelog_filename)
+     return()
+  }
 
   tryCatch(
     beastier::check_can_create_file(
