@@ -12,17 +12,14 @@
 #' }
 #' @author Richèl J.C. Bilderbeek
 do_minimal_run <- function() {
-  folder <- file.path(rappdirs::user_cache_dir(),
-    basename(
-      tempfile(pattern = "beastier_minimal_run_")
-    )
-  )
+  output_state_filename <- beastier::get_beastier_tempfilename()
   beastier::run_beast2_from_options(
     beastier::create_beast2_options(
       input_filename = beastier::get_beastier_path("2_4.xml"),
-      output_state_filename = file.path(folder, "out.xml.state"),
+      output_state_filename = output_state_filename,
       rng_seed = 314,
       beast2_path = beastier::get_default_beast2_path()
     )
   )
+  file.remove(output_state_filename)
 }
